<?php

// theme support functions
if ( ! isset( $content_width ) ) $content_width = 1042;
add_theme_support( 'post-thumbnails' );
add_theme_support( 'automatic-feed-links' );
add_theme_support( 'custom-background', array( 'default-color' => '9cf' ) ); // not used until 3.4
add_custom_background(); // depreciated in 3.4

// theme options file
require_once( get_template_directory() . '/options/theme-options.php' );

// pluralize nouns
function magomra_plural( $count, $noun, $echo = TRUE, $irregular = FALSE) {
	if( $irregular == FALSE ) {
		if( $count > 1 ) $return = $count . ' ' . $noun . 's';
		else $return = '1 ' . $noun;
	}
	
	if( $echo ) echo $return; else return $return;
}

function magomra_title_filter( $title, $sep, $seplocation ) {
// get special index page type (if any)
	$ssep = ' ' . $sep . ' ';

	if( is_category() ) $insert = $ssep . 'Category';
	elseif( is_tag() ) $insert = $ssep . 'Tag';
	elseif( is_author() ) $insert = $ssep . 'Author';
	elseif( is_year() || is_month() || is_day() ) $insert = $ssep . 'Archives';
	else $insert = null;

// get the page number (if any)
	if( get_query_var( 'paged' ) )
		$num = $ssep . get_query_var( 'paged' );
	else $num = null;

// concoct title
	$return = get_bloginfo( 'name' ) . $insert . $title . $num;

//return
	return $return;
}

function magomra_register_sidebar(){
// registers the dynamic sidebar
	$args = array(
		'name'          => 'Main Sidebar',
		'id'            => 'main_sidebar',
		'description'   => 'The main sidebar.',
		'before_widget' => '<li id="%1$s" class="widget %2$s">',
		'after_widget'  => '</li>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>' 
	);
	
	register_sidebar( $args );
}

function magomra_index_nav() {
	$next_posts = get_next_posts_link( '&laquo; Older' );
	$prev_posts = get_previous_posts_link( 'Newer &raquo;' );
	if( !empty( $next_posts ) )
		echo '<div class="post-navigation-next">' . $next_posts . '</div>';
	if( !empty( $prev_posts ) ) 
		echo '<div class="post-navigation-prev">' . $prev_posts  . '</div>'; 
}

function magomra_register_nav_menu(){
	register_nav_menu( 'navigation_menu', 'Navigation Menu' );
}

function magomra_nav_menu(){
	$args = array(
		'theme_location'  => 'navigation_menu',
		'container'       => false,
		'menu_class'      => 'menu', 
		'echo'            => true,
		'fallback_cb'     => 'wp_page_menu',
		'items_wrap'      => '<ul id="%1$s" class="%2$s">%3$s<div class="clear"></div></ul>',
		'depth'           => 3,
	);
	
	wp_nav_menu( $args );
}

// Custom callback to list comments in the your-theme style
function magomra_custom_comments($comment, $args, $depth) {
  $GLOBALS['comment'] = $comment;
    $GLOBALS['comment_depth'] = $depth;
  ?>
    <li id="comment-<?php comment_ID() ?>" <?php comment_class( 'response' ) ?>>
        <div class="comment-author response-author"><?php magomra_commenter_link() ?></div>
        <div class="comment-meta"><span class="comment-meta-span"><?php printf( 'Posted %1$s at %2$s | <a href="%3$s" title="Permalink to this comment">Permalink</a>',
                    get_comment_date(),
                    get_comment_time(),
                    '#comment-' . get_comment_ID() );
                    edit_comment_link( 'Edit', ' | <span class="edit-link">', '</span>'); ?></span></div>
  <?php if ($comment->comment_approved == '0') echo '<span class="unapproved">Your comment is awaiting moderation.'; ?>
          <div class="comment-content">
            <?php comment_text() ?>
        </div>
        <?php // echo the comment reply link
            if($args['type'] == 'all' || get_comment_type() == 'comment') :
                comment_reply_link(array_merge($args, array(
                    'reply_text' => __('Reply','your-theme'),
                    'login_text' => __('Log in to reply.','your-theme'),
                    'depth' => $depth,
                    'before' => '<div class="comment-reply">',
                    'after' => '</div>'
                )));
            endif;
        ?>
<?php } // end custom_comments

// Custom callback to list pings
function magomra_custom_pings($comment, $args, $depth) {
	$GLOBALS['comment'] = $comment; ?>
	<li id="comment-<?php comment_ID() ?>" <?php comment_class() ?>>
    	<div class="trackback-author"><?php printf( 'By %1$s on %2$s at %3$s',
                        get_comment_author_link(),
                        get_comment_date(),
                        get_comment_time() );
                        edit_comment_link( 'Edit', ' <span class="meta-sep">|</span> <span class="edit-link">', '</span>'); ?></div>
    <?php if ($comment->comment_approved == '0') echo '<span class="unapproved">Your trackback is awaiting moderation.'; ?>
            <div class="comment-content">
                <?php comment_text() ?>
            </div>
<?php } // end custom_pings

// Produces an avatar image with the hCard-compliant photo class
function magomra_commenter_link() {
    $commenter = get_comment_author_link();
    if ( ereg( '<a[^>]* class=[^>]+>', $commenter ) ) {
        $commenter = ereg_replace( '(<a[^>]* class=[\'"]?)', '\\1url ' , $commenter );
    } else {
        $commenter = ereg_replace( '(<a )/', '\\1class="url "' , $commenter );
    }
    $avatar_email = get_comment_author_email();
    $avatar = str_replace( "class='avatar", "class='photo avatar", get_avatar( $avatar_email, 80 ) );
    echo $avatar . ' <span class="fn n">' . $commenter . '</span>';
}

add_action( 'widgets_init', 'magomra_register_sidebar' );
add_action( 'admin_init', 'magomra_register_nav_menu' ); // if I use after_theme_setup here, then delete my menu, WordPress thinks the theme does not support custom menus.
add_filter( 'wp_title', 'magomra_title_filter', 10, 3 );

?>