<?php
function magomra_register_options() {
// register theme options
	register_setting( 'magomra-theme-options-group', 'magomra-theme-options', 'magomra_sanatize_input' );
}

function magomra_sanatize_input( $input ) {
	return $input;
}

function magomra_build_options() {
	
	$magomra_options = array (
		
		// SECTION: Display Options
		array( 
			'name' => 'Display Options', 
			'desc' => 'Options for displaying or hiding certain text and metadata.',
			'type' => 'section'
		),
	
		// show authors
		array( 
			'name' => 'Hide author link?',
			'id' => 'hide_post_author',
			'desc' => 'Hide link to author page on posts/pages?',
			'type' => 'checkbox',
		),
	
		// show published dates
		array( 
			'name' => 'Hide publication date?',
			'id' => 'hide_post_date',
			'desc' => 'Hide the date when each post or page was published?',
			'type' => 'checkbox',
			),
	
		array( 
			'name' => 'Post comment message:',
			'id' => 'post_comment_message',
			'desc' => 'The text to display under the new comment form. Can contain HTML tags. Leave blank for no message.',
			'type' => 'textarea',
			'default' => 'Your email address will <em>never</em> be published.'
			),
		
		array( 
			'name' => 'Title seperator character:',
			'id' => 'title_sep_char',
			'desc' => 'The character used to seperate pieces of information in the title.',
			'type' => 'text',
			'default' => '|'
			),
		
	array( 'type' => 'close' )
);

return $magomra_options; 
}

function magomra_default_options() {
	$default_options = array();
	$magomra_options = magomra_build_options();
	foreach( $magomra_options as $magomra_option )
		if( isset( $magomra_option['default'] ) ) 
			$default_options = array_merge( $default_options, array( $magomra_option['id'] => $magomra_option['default'] ) );

	return $default_options;
}

function magomra_theme_options_init() {
// enque options page supporting CSS and scripts
	wp_enqueue_style( 'magomra-theme-options-style', get_template_directory_uri() . '/options/theme-options.css' );
}

function magomra_create_menu() {
//create menu link in Appearance menu
	add_theme_page( 'Magomra Theme Options', 'Theme Options', 'edit_theme_options', 'magomra-theme-options', 'magomra_options_page' );
}

function magomra_options_page() {
if( isset( $_POST['reset'] ) ) {
	delete_option( 'magomra-theme-options' );
	wp_cache_flush(); 
	add_option( 'magomra-theme-options', magomra_default_options(), NULL, false );
	echo '<div class="updated settings-error"><p><strong>Magomra theme options reset to defaults.</strong></p></div>';
}

elseif( isset( $_REQUEST['settings-updated'] ) )
	echo '<div class="updated settings-error"><p><strong>Magomra theme options saved.</strong></p></div>';

?>

<div class="wrap">
<?php screen_icon(); ?><h2>Magomra Theme Options</h2>

<form method="post" action="options.php">
<table class="form-table"><tbody>

<?php 
settings_fields( 'magomra-theme-options-group' ); 
$options = get_option( 'magomra-theme-options', magomra_default_options() );
$magomra_options = magomra_build_options();



foreach( $magomra_options as $item ) {
if( isset( $item['id']) ) $item_id = $item['id'];

switch ( $item['type'] ) {

case 'section' : ?>

	<tr valign="center"><th scope="row"><h3 class="section-title"><?php echo $item['name']; ?></h3></th>
	<td><?php // echo $item['desc']; ?></td></tr>

<?php break;

case 'text': ?>

	<tr valign="top"><th scope="row"><label for="<?php echo 'magomra-theme-options[' . $item_id . ']'; ?>"><?php echo $item['name']; ?></label></th>
		<td><input name="<?php echo 'magomra-theme-options[' . $item_id . ']'; ?>" id="<?php echo 'magomra-theme-options[' . $item_id . ']'; ?>" type="<?php echo $item['type']; ?>" value="<?php if( isset(  $options[$item_id] ) ) esc_attr_e( $options[$item_id] ); else esc_attr_e( $item['default'] ); ?>" />
		</td></tr>

<?php break;

case 'textarea': ?>

	<tr valign="top"><th scope="row"><label for="<?php echo 'magomra-theme-options[' . $item_id . ']'; ?>"><?php echo $item['name']; ?></label></th>
		<td><textarea name="<?php echo 'magomra-theme-options[' . $item_id . ']'; ?>" type="<?php echo 'magomra-theme-options[' . $item_id . ']'; ?>" cols="" rows=""><?php if( isset( $options[$item_id] ) )  esc_attr_e( $options[$item_id] ); else esc_attr_e( $item['default'] ); ?></textarea>
		</td></tr>

<?php break;

case 'select': ?>

<tr valign="top"><th scope="row">
<label for="<?php echo 'magomra-theme-options[' . $item_id . ']'; ?>"><?php echo $item['name']; ?></label></th>
		<td><select name="<?php echo 'magomra-theme-options[' . $item_id . ']'; ?>" id="<?php echo 'magomra-theme-options[' . $item_id . ']'; ?>">
		<?php foreach( $item['options'] as $suboption ) { ?>
				<option <?php if ( $options[$item_id] == $suboption) { echo 'selected="selected"'; } ?>><?php echo $suboption; ?></option>
		<?php } ?>
		</select>
		</span>
	</td></tr>

<?php break;

case "radio": ?>

<tr valign="top"><th scope="row">
	<label for="<?php echo 'magomra-theme-options[' . $item_id . ']'; ?>"><?php echo $item['name']; ?></label>		  <?php 
		foreach ( $item['options'] as $key=>$suboption) {
			if( isset( $options[$item_id] ) ) {
				if( $key == $options[$item_id] ) { $checked = 'checked="checked"'; }
				else { $checked = NULL; }
			} 
			
			else {
				if( $key == $item['default'] ) { $checked = 'checked="checked"'; }
				else { $checked = NULL; }
			} ?>

			<td><input type="radio" id="<?php echo 'magomra-theme-options[' . $item_id . ']'; ?>" name="<?php echo 'magomra-theme-options[' . $item_id . ']'; ?>" value="<?php echo $key; ?>" <?php echo $checked; ?> /><?php echo $suboption; ?><br />
		<?php } ?>
		
	</td></th>

<?php break;

case "checkbox": ?>

	<?php if( isset( $options[$item_id] ) ) $checked = 'checked="checked"'; else $checked = NULL; ?>

<tr valign="top"><th scope="row">
<label for="<?php echo 'magomra-theme-options[' . $item_id . ']'; ?>"><?php echo $item['name']; ?></label>

</th>
		<td><input type="checkbox" name="<?php echo 'magomra-theme-options[' . $item_id . ']'; ?>" id="<?php echo 'magomra-theme-options[' . $item_id . ']'; ?>" value="1" <?php echo $checked; ?> /></td></tr>

<?php break;

case "close": ?>

</tbody></table>

<?php break;
	}
}
?>

<div class="submit-container">

<div class="submit">
<input class="button button-primary" type="submit" name="save" value="Save All Changes" />
</div>
</form>

<form method="post" action="">

<div class="button-right" type="submit">

<input class="button button-secondary" type="submit" name="reset" value="Reset to Defaults" />
<input type="hidden" name="action" value="reset" />

</div>

</form>
<div class="clear">&nbsp;</div>
</div>

</div>

<?php 
} 

// Hooks & Filters
add_action( 'admin_init', 'magomra_register_options' ); // register theme settings
add_action( 'admin_menu', 'magomra_create_menu' );
add_action( 'admin_init', 'magomra_theme_options_init' );
?>